Crate yamos6502

Crate yamos6502 

Behavioral emulator of MOS 6502

Structs

Mos6502
Behavioral MOS 6502 emulator
RegisterFile
MOS 6502 register file

Enums

AddressMode
Insn
Instruction representation. Nor particulary space-efficient (perhaps makes the code slower, too?), yet readable.
MemoryError
Memory errors
Register
Register
RunError
Run error
RunExit
Run normal exit
StackWraparound
Stack wraparound policy
Status
SR Flags (bit 7 to bit 0)

Constants

IRQ_BRK_VECTOR
When an interrupt is signaled (hardware or the software via BRK), the low and the high 8 bits of the program counter are loaded from a word at this address.
MAX_MEMORY_SIZE
No more than 64 KiB of memory is supported
NMI_VECTOR
When an non-maskable interrupt is signaled, the low and the high 8 bits of the program counter from a word at this address.
RESET_VECTOR
When a reset is requested, the low and the high 8 bits of the program counter are loaded from a word at this address.
STACK_BOTTOM
Bottom of the stack

Traits

Memory
A 16-bit addressable, 8-bit cell memory

Functions

decode_insn
encode_insn
get_opcode_string